@@ -1,8 +1,10 @@
 package PerlIO::Util;
 
+use 5.008_001;
+
 use strict;
 
-our $VERSION = '0.49_03';
+our $VERSION = '0.59_01';
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -33,7 +35,7 @@ PerlIO::Util - A selection of general PerlIO utilities
 
 =head1 VERSION
 
-This document describes PerlIO::Util version 0.49_03
+This document describes PerlIO::Util version 0.59_01
 
 =head1 SYNOPSIS
 
@@ -41,19 +43,19 @@ This document describes PerlIO::Util version 0.49_03
 
     # utility layers
 
-    open $in, "+<:flock", ...; # with flock(IN, LOCK_EX)
+    open $in, '+<:flock', ...; # with flock(IN, LOCK_EX)
 
-    open $in, "+<:creat :excl", ...; # with O_CREAT | O_EXCL
+    open $in, '+<:creat :excl', ...; # with O_CREAT | O_EXCL
 
-    open $out, ">:tee", $file, \$scalar, \*STDERR;
-    print $out "foo"; # print to $file, $scalar and *STDERR
+    open $out, '>:tee', 'file.txt', \$scalar, \*STDERR;
+    print $out 'foo'; # print to 'file.txt', $scalar and *STDERR
 
     # utility routines
 
     $fh = PerlIO::Util->open('<', $file); # it dies on fail
 
     *STDOUT->push_layer(scalar => \$s); # it dies on fail
-    print "foo";
+    print 'foo';
 
     print *STDOUT->pop_layer(); # => scalar
     print $s; # => foo
@@ -106,15 +108,15 @@ See L<PerlIO::reverse>.
 
 =head2 :fse
 
-Mediation of encodings
+Mediation of filesystem encoding.
 
-See L<PerlIO::fse>
+See L<PerlIO::fse>.
 
 =head1 UTILITY METHODS
 
-=head2 PerlIO::Util-E<gt>open(I<mode>, I<args>)
+=head2 PerlIO::Util->open(I<mode>, I<args>)
 
-Calls built-in C<open()>, and returns an anonymus C<IO::Handle> instance.
+Calls built-in C<open()>, and returns an anonymous C<IO::Handle> instance.
 It dies on fail.
 
 Unlike Perl's C<open()> (nor C<IO::File>'s), I<mode> is always required. 
@@ -123,26 +125,26 @@ Unlike Perl's C<open()> (nor C<IO::File>'s), I<mode> is always required.
 
 Returns the known layer names.
 
-=head2 I<FILEHANDLE>-E<gt>get_layers( )
+=head2 I<FILEHANDLE>->get_layers( )
 
 Returns the names of the PerlIO layers on I<FILEHANDLE>.
 
 See L<PerlIO/Querying the layers of filehandles>.
 
-=head2 I<FILEHANDLE>-E<gt>push_layer(I<layer> [ => I<arg>])
+=head2 I<FILEHANDLE>->push_layer(I<layer> [ => I<arg>])
 
 Almost equivalent to C<binmode(FILEHANDLE, ':layer(arg)')>, but accepts
 any type of I<arg>, e.g. a scalar reference to the C<:scalar> layer.
 
 This method dies on fail. Otherwise, it returns I<FILEHANDLE>.
 
-=head2 I<FILEHANDLE>-E<gt>pop_layer( )
+=head2 I<FILEHANDLE>->pop_layer( )
 
 Equivalent to C<binmode(FILEHANDLE, ':pop')>. It removes a top level layer
 from I<FILEHANDLE>, but note that you cannot remove dummy layers such as
 C<:utf8> or C<:flock>.
 
-This method returns the name of the poped layer.
+This method returns the name of the popped layer.
 
 =head1 DEPENDENCIES
 
@@ -153,7 +155,7 @@ Perl 5.8.1 or later, and a C compiler.
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-E<lt>gfuji (at) cpan.orgE<gt>, or through the web interface at
+E<lt>gfuji(at)cpan.orgE<gt>, or through the web interface at
 L<http://rt.cpan.org/>.
 
 =head1 SEE ALSO
@@ -165,13 +167,17 @@ L<PerlIO> for C<push_layer()> and C<pop_layer()>.
 
 L<perliol> for implementation details.
 
+L<perlfunc/open>.
+
+L<perlopentut>.
+
 =head1 AUTHOR
 
-Goro Fuji (藤 吾郎) E<lt>gfuji (at) cpan.orgE<gt>
+Goro Fuji (藤 吾郎) E<lt>gfuji(at)cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2008, Goro Fuji E<lt>gfuji (at) cpan.orgE<gt>. Some rights reserved.
+Copyright (c) 2008, Goro Fuji E<lt>gfuji(at)cpan.orgE<gt>. Some rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
